<?php
//based on https://www.drupal.org/docs/8/modules/social-api/social-api-1x/social-auth-1x/social-auth-eventsubscriber-example-module

namespace Drupal\social_auth_roles\EventSubscriber;

use Drupal\social_auth\Event\SocialAuthUserEvent;
use Drupal\social_auth\Event\SocialAuthEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Reacts on Social Auth events.
 */
class SocialAuthSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   *
   * Returns an array of event names this subscriber wants to listen to.
   * For this case, we are going to subscribe for user creation and login
   * events and call the methods to react on these events.
   */
  public static function getSubscribedEvents() {
    $events[SocialAuthEvents::USER_CREATED] = ['onUserCreated'];

    return $events;
  }
  
  /**
   * Alters the user name.
   *
   * @param \Drupal\social_auth\Event\SocialAuthUserEvent $event
   *   The Social Auth user event object.
   */
  public function onUserCreated(SocialAuthUserEvent $event) {
    /**
     * @var Drupal\user\UserInterface $user
     *
     * For all available methods, see User class
     * @see https://api.drupal.org/api/drupal/core!modules!user!src!Entity!User.php/class/User
     */
    $config = \Drupal::config('social_auth_roles.settings');
    $addRoles = $config->get('social_auth_roles');
    $user = $event->getUser();
    foreach($addRoles AS $role) {
      if($role !== 0){
	$user->addRole($role);
        \Drupal::logger('social_auth_roles')->notice('Role "'. $role . '" added to new user ' . $user->getDisplayName());
      }
    }
  }
}
