<?php
// based on https://www.drupal.org/docs/8/api/configuration-api/working-with-configuration-forms
// also based on permissions_by_term Module

namespace Drupal\social_auth_roles\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class socialAuthRolesSettingsForm extends ConfigFormBase {
  /** 
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_auth_roles_login_admin_settings';
  }

  /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'social_auth_roles.settings',
    ];
  }

  /** 
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('social_auth_roles.settings');

    // Get all roles for 
    $availableRoles = [];
    foreach (user_roles() as $user_role_id => $user_role_name) {
      if($user_role_id != 'anonymous' && $user_role_id !='authenticated') {
        $availableRoles[$user_role_id] = $user_role_name->label();
      }
    }

    $aSetRoles = $config->get('social_auth_roles');

    $description = 'Select user roles that will be assigned on User Creation via the Social Auth.';

    // Now, lets do the Roles table.
    $form['social_auth_roles'] = [
      '#type'          => 'checkboxes',
      '#title'         => t('New Social User roles'),
      '#description'   => t($description),
      '#default_value' => $aSetRoles,
      '#options'       => $availableRoles,
      '#multiple'      => TRUE,
      '#weight'        => 5,
    ];

    return parent::buildForm($form, $form_state);
  }

  /** 
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
      // Retrieve the configuration
       $this->configFactory->getEditable('social_auth_roles.settings')
      ->set('social_auth_roles', $form_state->getValue('social_auth_roles'))
      ->save();
   
    parent::submitForm($form, $form_state);
  }
}
